animationsys = {}

function animationsys:update(dt)
	self:handleAnimation(dt)
	self:handleMorphs(dt)
end

function animationsys:handleAnimation(dt)
	local entities = entitymgr:getEntities(cAnimation.name)

	for i, eId in ipairs(entities) do
		local anim = entitymgr:getComponent(eId, cAnimation.name)
		local draw = entitymgr:getComponent(eId, cDrawable.name)

		if anim then
			anim.elapsedTime = anim.elapsedTime + dt
			ft = 1 / anim.fps
			if anim.elapsedTime > ft then
				anim.elapsedTime = anim.elapsedTime - ft
				draw.currentFrame = draw.currentFrame + anim.direction
				if draw.currentFrame > anim.endFrame then
					if anim.mode == "loop" then 
						draw.currentFrame = anim.startFrame
					elseif anim.mode == "pingpong" then
						draw.currentFrame = anim.endFrame
						anim.direction = -1
					else
						draw.currentFrame = anim.endFrame
						anim.direction = 0
					end
				elseif draw.currentFrame < anim.startFrame then
					if anim.mode == "pingpong" then
						draw.currentFrame = anim.startFrame
						anim.direction = 1
					elseif anim.mode == "loop" then
						draw.currentFrame = anim.endFrame
					else
						draw.currentFrame = anim.startFrame
						anim.direction = 0
					end
				end
			end
		end
	end
end

function animationsys:handleMorphs(dt)
	local entities = entitymgr:getEntities(cMorph.name)

	for i, eId in ipairs(entities) do
		local morph = entitymgr:getComponent(eId, cMorph.name)

		morph.elapsedTime = morph.elapsedTime + dt
		local progress = morph.elapsedTime / morph.totalTime
		
		if progress > 1 then 
			local event = entitymgr:getComponent(eId, cEventCallback.name)
			if event then event.func(eId, event.data) end
		else
			local w = morph.startSize.x + (morph.endSize.x - morph.startSize.x) * progress
			local h = morph.startSize.y + (morph.endSize.y - morph.startSize.y) * progress

			local pos = entitymgr:getComponent(eId, cPosition.name)
			if pos then
				pos.x = morph.startPos.x + (morph.endPos.x - morph.startPos.x) * progress
				pos.y = morph.startPos.y + (morph.endPos.y - morph.startPos.y) * progress
			end

			local stencil = entitymgr:getComponent(eId, cStencil.name)
			if stencil and stencil.mode == "rectangle" then
				stencil.width = w
				stencil.height = h
			end
		end
	end
end