drawsys = {}

function drawsys:draw()
	self:drawables()
	self:drawText()
end

function drawsys:drawables()
	local entities = entitymgr:getEntities(cDrawable.name)
	
	for i, eId in ipairs(entities) do
		local draw = entitymgr:getComponent(eId, cDrawable.name)
		
		if draw and draw.visible then
			if draw.shape then
				self:drawShapes(eId, draw)
			elseif draw.image then
				self:drawImages(eId, draw)
			end
		end
	end
end

function drawsys:drawImages(eId, draw)
	local pos = entitymgr:getComponent(eId, cPosition.name)
	if not pos then return end

	love.graphics.setColor(unpack(draw.color))

	local img = factory:getImage(draw.image)
	local sx = draw.width / (img:getWidth() / draw.frames)
	local sy = draw.height / img:getHeight()

	if draw.frames > 1 then
		love.graphics.setScissor(pos.x, pos.y, draw.width, draw.height)
		love.graphics.draw(img, pos.x - (draw.currentFrame - 1) * draw.width, pos.y, pos.rot, sx, sy)
		love.graphics.setScissor()
	else
		love.graphics.draw(img, pos.x, pos.y, pos.rot, sx, sy)
	end
end

function drawsys:drawShapes(eId, draw)
	local pos = entitymgr:getComponent(eId, cPosition.name)
	if not pos then return end
	
	love.graphics.setColor(unpack(draw.color))
	
	local fillMode = "fill"
	if draw.fill == false then fillMode = "line" end

	if draw.shape == "square" then
		love.graphics.rectangle(fillMode, pos.x, pos.y, draw.width, draw.height)
	elseif draw.shape == "circle" then
		love.graphics.circle(fillMode, pos.x, pos.y, draw.radius)
	end
end

function drawsys:drawText()
	local entities = entitymgr:getEntities(cText.name)
	
	for i, eId in ipairs(entities) do
		local pos = entitymgr:getComponent(eId, cPosition.name)
		local text = entitymgr:getComponent(eId, cText.name)
		
		if pos and text and text.visible then
			local font = factory:getFont(text.font, text.size)
			love.graphics.setFont(font)
			
			local x, y, w = self:getTextPositionAndSize(text, pos)
			
			if text.shadowOffset > 0 then
				love.graphics.setColor(unpack(text.shadowColor))
				love.graphics.printf(text.str, x + text.shadowOffset, y + text.shadowOffset, w, text.align)
			end
			
			love.graphics.setColor(unpack(text.color))
			love.graphics.printf(text.str, x, y, w, text.align)
		end
	end
	
	love.graphics.setColor(255, 255, 255)
end

function drawsys:getTextPositionAndSize(text, pos)
	local font = factory:getFont(text.font, text.size)
	local x, y = pos.x, pos.y
	local maxW = text.maxWidth
	if maxW == 0 then maxW = win.x end
	local w, lines = font:getWrap(text.str, maxW)
	
	if text.valign == "bottom" then
		y = pos.y - font:getHeight() * lines
	elseif text.valign == "middle" then
		y = pos.y - (font:getHeight() * lines) / 2
	end
	
	if text.align == "right" then
		x = pos.x - w
	elseif text.align == "center" then
		x = pos.x - w / 2
	end
	
	return x, y, w, font:getHeight()
end