entitymgr = {}
entitymgr.entities = {}
local entityCount = 0

function entitymgr:nextId()
	entityCount = entityCount + 1
	return entityCount
end

function entitymgr:addEntity(components)
	local e = {}
	e.id = self:nextId()
	self.entities[e.id] = e
	self:addComponents(e.id, components)
	
	return e.id
end

function entitymgr:addEntities(list)
	for i, v in ipairs(list) do 
		if not v.id then v.id = self:nextId() end
		self.entities[v.id] = v 
	end
end

function entitymgr:addComponents(eId, components)
	if self.entities[eId] then
		for i, v in ipairs(components) do
			self.entities[eId][v.name] = v.data
		end
	end		
end 

function entitymgr:addComponent(eId, component)
	if self.entities[eId] then
		self.entities[eId][component.name] = component.data
	end		
end 

function entitymgr:removeEntity(eId)
	local entity = self.entities[eId]
	self.entities[eId] = nil
	return entity
end

function entitymgr:removeAll()
	local list = {}
	
	for i = 1, entityCount do
		if self.entities[i] then table.insert(list, self.entities[i]) end
	end
	
	self.entities = {}
	
	return list
end

function entitymgr:removeAllWithComponent(componentName)
	local list = {}
	
	for i = 1, entityCount do
		if self.entities[i] and self.entities[i][componentName] then 
			table.insert(list, self:remove(i)) 
		end
	end
	
	return list
end

function entitymgr:removeComponent(eId, componentName)
	if self.entities[eId] then self.entities[eId][componentName] = nil end
end

function entitymgr:removeAllOfComponent(componentName)
	for i = 1, entityCount do 
		self:removeComponent(i) 
	end		
end

function entitymgr:getEntities(componentName)
	local list = {}
	
	for i = 1, entityCount do
		if self.entities[i] and self.entities[i][componentName] then table.insert(list, self.entities[i].id) end
	end
	
	return list
end

function entitymgr:getComponent(eId, componentName)
	if self.entities[eId] then return self.entities[eId][componentName] end
end