positionsys = {}

function positionsys:update(dt)
	local entities = entitymgr:getEntities(cPosition.name)

	for i, eId in ipairs(entities) do
		local pos = entitymgr:getComponent(eId, cPosition.name)
		local move = entitymgr:getComponent(eId, cMoveable.name)

		if move then
			pos.x = pos.x + move.direction.x * move.speed * dt
			pos.y = pos.y + move.direction.y * move.speed * dt
		end

		self:handleBounds(eId, pos)
	end
end

function positionsys:handleBounds(eId, pos)
	local minX, minY

	local draw = entitymgr:getComponent(eId, cDrawable.name)
	local text = entitymgr:getComponent(eId, cText.name)
	if draw and draw.visible then
		minX = -draw.width
		minY = -draw.height
	elseif text and text.visible then
			local font = factory:getFont(text.font, text.size)
			local x, y, w, h = drawsys:getTextPositionAndSize(text, pos)
			minX = -w
			minY = -h
	else
		return
	end

	if pos.x < minX or pos.x > win.x or pos.y < minY or pos.y > win.y then
		local event = entitymgr:getComponent(eId, cEventCallback.name)
		local handled = false

		if pos.outOfBounds then
			if pos.outOfBounds.gotoX then pos.x = pos.outOfBounds.gotoX end
			if pos.outOfBounds.gotoY then pos.y = pos.outOfBounds.gotoY end
			handled = true
		end
		if event then 
			event.func(eId, event.data) 
			handled = true 
		end
		if not handled then entitymgr:remove(eId) end
	end
end
