local s = {}

function s:open()
	if not self.entities then
		local y1 = win.y / 4

		entitymgr:addEntity{
			{ name = cPosition.name, data = cPosition.new{ x = 0, y = y1 } },
			{ name = cDrawable.name, data = cDrawable.new{ shape = "square", fill = true, color = { 30, 30, 30 }, width = win.x, height = win.y / 2 } },
			{ name = cEventCallback.name, data = cEventCallback.new{ func = s.onLightning, data = "flash" } },
			{ name = cTimeout.name, data = cTimeout.new{ timer = math.random(4, 8), removeAfter = false } }
		}
		entitymgr:addEntity{
			{ name = cPosition.name, data = cPosition.new{ x = win.x / 5, y = y1 + win.x / 9 } },
			{ name = cDrawable.name, data = cDrawable.new{ shape = "circle", fill = true, color = { 160, 160, 160 }, radius = win.x / 10 } }
		}
		entitymgr:addEntity{
			{ name = cPosition.name, data = cPosition.new{ x = 0, y = y1 } },
			{ name = cDrawable.name, data = cDrawable.new{ image = "skyline.gif", width = win.x, height = win.y / 2 } }
		}
		local size = win.x / 16
		for i = 0, 16 do
			for j = 0, 5 do
				entitymgr:addEntity{
					{ name = cPosition.name, data = cPosition.new{ x = i * size, y = y1 + j * size, outOfBounds = { gotoX = win.x } } },
					{ name = cDrawable.name, data = cDrawable.new{ image = "rain.png", width = size, height = size, color = { 255, 255, 255, 64 }, frames = 2 } },
					{ name = cAnimation.name, data = cAnimation.new{ fps = 8, endFrame = 2 } },
					{ name = cMoveable.name, data = cMoveable.new{ direction = { x = -1, y = 0 }, speed = win.x / 200 } }
				}
			end
		end
		entitymgr:addEntity{
			{ name = cPosition.name, data = cPosition.new{ x = win.x, y = y1 } },
			{ name = cText.name, data = cText.new{ str = "Escape", align = "right", valign = "bottom", 
				size = win.y / 6, color = {66, 66, 66} } }
		}
		entitymgr:addEntity{
			{ name = cPosition.name, data = cPosition.new{ x = win.x - 10, y = win.y - 10} },
			{ name = cText.name, data = cText.new{ str = "A game by Andreas Hedin\nwww.andreashedin.com", 
				align = "right", size = win.y / 36, valign = "bottom", color = {66, 66, 66} } }
		}
		entitymgr:addEntity{
			{ name = cPosition.name, data = cPosition.new{ x = 10, y = win.y - 10} },
			{ name = cText.name, data = cText.new{ str = "Made with Love\nwww.love2d.org", 
				align = "left", size = win.y / 36, valign = "bottom", color = {66, 66, 66} } }
		}
		entitymgr:addEntity{
			{ name = cPosition.name, data = cPosition.new{ x = win.x - 10, y = y1 + win.y / 2 + 10 } },
			{ name = cText.name, data = cText.new{ str = "Quit", align = "right", size = win.y / 18, color = { 66, 66, 66 } } },
			{ name = cGui.name, data = cGui.new{ hover = { color = { 140, 14, 14 } }, shortcut = "escape" } },
			{ name = cEventCallback.name, data = cEventCallback.new{ func = function () love.event.quit() end } }
		}
		entitymgr:addEntity{
			{ name = cPosition.name, data = cPosition.new{ x = win.x - win.x / 6, y = y1 + win.y / 2 + 10} },
			{ name = cText.name, data = cText.new{ str = "Settings", align = "right", size = win.y / 18, color = { 66, 66, 66 } } },
			{ name = cGui.name, data = cGui.new{ hover = { color = { 140, 14, 14 } } } },
			{ name = cEventCallback.name, data = cEventCallback.new{ func = s.changeScene, data = "settings" } }
		}
		entitymgr:addEntity{
			{ name = cPosition.name, data = cPosition.new{ x = win.x - win.x / 2.3, y = y1 + win.y / 2 + 10 } },
			{ name = cText.name, data = cText.new{ str = "Play", align = "right", size = win.y / 18, color = { 66, 66, 66 } } },
			{ name = cGui.name, data = cGui.new{ hover = { color = { 140, 14, 14 } } } },
			{ name = cEventCallback.name, data = cEventCallback.new{ func = s.changeScene, data = "game" } }
		}
	else
		entitymgr:addEntities(self.entities)
	end
end

function s:close()
	s.entities = entitymgr:removeAll()
end

function s:update(dt)
	positionsys:update(dt)
	animationsys:update(dt)
	guisys:update(dt)
	timersys:update(dt)
end

function s:draw()
	drawsys:draw()
end

function s:pause()

end

function s:unpause()

end

function s.changeScene(eId, data)
	scenemgr:open(data)
end

function s.onLightning(eId, data)
	local draw = entitymgr:getComponent(eId, cDrawable.name)
	local timeout = entitymgr:getComponent(eId, cTimeout.name)
	local event = entitymgr:getComponent(eId, cEventCallback.name)
	
	if data == "flash" or data == "flash2" then
		draw.color = { 255, 255, 255 }
		timeout.timer = 0.1
		if data == "flash" then	event.data = "short"
		else event.data = "long" end
	elseif data == "short" or data == "long" then
		draw.color = { 30, 30, 30 }
		if data == "short" then
			timeout.timer = 0.1
			event.data = "flash2"
		else
			timeout.timer = math.random(6, 16)
			event.data = "flash"
		end
	end
end

return s