local s = {}

function s:open()
	if not self.entities then
		self.entities = {}
		local y1 = win.y / 4

		entitymgr:addEntity{
			{ name = cPosition.name, data = cPosition.new{ x = 0, y = y1 } },
			{ name = cDrawable.name, data = cDrawable.new{ shape = "square", fill = true, color = { 30, 30, 30 }, width = win.x, height = win.y / 2 } }
		}
		entitymgr:addEntity{
			{ name = cPosition.name, data = cPosition.new{ x = win.x / 5, y = y1 + win.x / 9 } },
			{ name = cDrawable.name, data = cDrawable.new{ shape = "circle", fill = true, color = { 160, 160, 160 }, radius = win.x / 10 } }
		}
		entitymgr:addEntity{
			{ name = cPosition.name, data = cPosition.new{ x = 0, y = y1 } },
			{ name = cDrawable.name, data = cDrawable.new{ image = "skyline.gif", width = win.x, height = win.y / 2 } }
		}
		local size = win.x / 16
		for i = 0, 16 do
			for j = 0, 5 do
				entitymgr:addEntity{
					{ name = cPosition.name, data = cPosition.new{ x = i * size, y = y1 + j * size, outOfBounds = { gotoX = win.x } } },
					{ name = cDrawable.name, data = cDrawable.new{ image = "rain.png", width = size, height = size, color = { 255, 255, 255, 64 }, frames = 2 } },
					{ name = cAnimation.name, data = cAnimation.new{ fps = 8, endFrame = 2 } },
					{ name = cMoveable.name, data = cMoveable.new{ direction = { x = -1, y = 0 }, speed = win.x / 200 } }
				}
			end
		end
		entitymgr:addEntity{
			{ name = cPosition.name, data = cPosition.new{ x = win.x, y = y1} },
			{ name = cText.name, data = cText.new{ str = "Settings", align = "right", valign = "bottom", 
				size = win.y / 6, color = {66, 66, 66} } }
		}
		entitymgr:addEntity{
			{ name = cPosition.name, data = cPosition.new{ x = win.x - 10, y = win.y - 10} },
			{ name = cText.name, data = cText.new{ str = "A game by Andreas Hedin\nwww.andreashedin.com", 
				align = "right", size = win.y / 36, valign = "bottom", color = {66, 66, 66} } }
		}
		entitymgr:addEntity{
			{ name = cPosition.name, data = cPosition.new{ x = 10, y = win.y - 10} },
			{ name = cText.name, data = cText.new{ str = "Made with Love\nwww.love2d.org", 
				align = "left", size = win.y / 36, valign = "bottom", color = {66, 66, 66} } }
		}
		local w, h, fullscreen = love.graphics.getMode()
		local fsStr = "Off"
		if fullscreen then fsStr = "On" end
		local eId = entitymgr:addEntity{
			{ name = cPosition.name, data = cPosition.new{ x = win.x - win.x / 4, y = y1 + win.y / 2 + win.y / 36 + 10 } },
			{ name = cText.name, data = cText.new{ str = fsStr, align = "left", size = win.y / 36, color = {66, 66, 66} } },
			{ name = cToggle.name, data = cToggle.new{ on = fullscreen } }
		}
		entitymgr:addEntity{
			{ name = cPosition.name, data = cPosition.new{ x = win.x - 10, y = y1 +win.y / 2 + 10 } },
			{ name = cText.name, data = cText.new{ str = "Back", align = "right", size = win.y / 18, color = {66, 66, 66} } },
			{ name = cGui.name, data = cGui.new{ hover = { color = { 140, 14, 14 } }, shortcut = "escape" } },
			{ name = cEventCallback.name, data = cEventCallback.new{ func = s.onBackCallback, data = eId } }
		}
		entitymgr:addEntity{
			{ name = cPosition.name, data = cPosition.new{ x = win.x - win.x / 4, y = y1 + win.y / 2 + 10 } },
			{ name = cText.name, data = cText.new{ str = "Fullscreen", align = "right", size = win.y / 18, color = {66, 66, 66} } },
			{ name = cGui.name, data = cGui.new{ hover = { color = { 140, 14, 14 } } } },
			{ name = cEventCallback.name, data = cEventCallback.new{ func = s.onFullscreenCallback, data = eId } }
		}
	else
		entitymgr:addEntities(self.entities)
	end
end

function s:close()
	s.entities = entitymgr:removeAll()
end

function s:update(dt)
	positionsys:update(dt)
	animationsys:update(dt)
	guisys:update(dt)
end

function s:draw()
	drawsys:draw()
end

function s:pause()

end

function s:unpause()

end

function s.onFullscreenCallback(eId, data)
	local toggle = entitymgr:getComponent(data, cToggle.name)
	local text = entitymgr:getComponent(data, cText.name)
	
	if toggle and text then
		if not toggle.on then
			toggle.on = true
			text.str = "On"
		else
			toggle.on = false
			text.str = "Off"
		end
	end
end

function s.onBackCallback(eId, data)
	local w, h, fs, vs, fsaa = love.graphics.getMode()
	local newFs = entitymgr:getComponent(data, cToggle.name).on

	if fs ~= newFs then love.graphics.setMode(w, h, newFs, vs, fsaa) end
	
	scenemgr:open("menu")
end

return s